==> s-component-0.0.1-alpha.0.tgz: package/example/pages/index/index.js <==
/**
 * @file list component
 * @author LipengJia
 */

/* globals Page, swan */
Page({ // eslint-disable-line
    data: {
        feedItem: {
            title: '超出两行了啊哈哈哈哈怎么办啊一样一样超出两行了啊哈哈哈哈怎么办啊一样一样超出两行了啊哈哈哈哈怎么办啊一样一样',
            infoSource: '网易新闻',
            commentsNum: 11,
            // images: [`https://hiphotos.baidu.com/fex/%70%69%63/item/e4dde71190ef76c6952c82ce9016fdfaae51675c.jpg`, `https://hiphotos.baidu.com/fex/%70%69%63/item/e4dde71190ef76c6952c82ce9016fdfaae51675c.jpg`, `https://hiphotos.baidu.com/fex/%70%69%63/item/e4dde71190ef76c6952c82ce9016fdfaae51675c.jpg`]
        },
        video: {
            isVideo: true,
            time: '05:00'
        },
        steps: [
            {
                text: '步骤一五个字',
                icon: 'home'
            },
            {
                text: '十个字十个字十个字啊',
                // icon: 'head',
                activeIcon: 'head'
            },
            {
                text: '十个字十个字十个字啊',
                // icon: 'head',
                activeIcon: 'head'
            },
            {
                text: '十个字十个字十个字啊',
                // icon: 'head',
                activeIcon: 'head'
            },
            {
                text: '十个字十个字十个字啊',
                // icon: 'head',
                activeIcon: 'head'
            },
            {
                text: '步骤三'
            }
        ],
        step: 0
    },
    feedItemTap() {
        console.log('feed-item 点击回调');
    },
    prev() {
        this.data.step > 0 && this.setData({
            step: this.data.step - 1
        });
    },

    next() {
        console.log('下一步', this.data);
        this.data.step < this.data.steps.length && this.setData({
            step: this.data.step + 1
        });
    }
});

==> s-component-0.0.2-alpha.0.tgz: package/example/pages/index/index.js <==
/**
 * @file list component
 * @author LipengJia
 */

/* globals Page, swan */
Page({ // eslint-disable-line
    data: {
        feedItem: {
            title: '超出两行了啊哈哈哈哈怎么办啊一样一样超出两行了啊哈哈哈哈怎么办啊一样一样超出两行了啊哈哈哈哈怎么办啊一样一样',
            infoSource: '网易新闻',
            commentsNum: 11,
            images: [`https://hiphotos.baidu.com/fex/%70%69%63/item/e4dde71190ef76c6952c82ce9016fdfaae51675c.jpg`, `https://hiphotos.baidu.com/fex/%70%69%63/item/e4dde71190ef76c6952c82ce9016fdfaae51675c.jpg`, `https://hiphotos.baidu.com/fex/%70%69%63/item/e4dde71190ef76c6952c82ce9016fdfaae51675c.jpg`]
        },
        video: {
            isVideo: false,
            time: '05:00'
        },
        steps: [
            {
                text: '步骤一五个字',
                icon: 'home'
            },
            {
                text: '十个字十个字十个字啊',
                // icon: 'head',
                activeIcon: 'head'
            },
            {
                text: '十个字十个字十个字啊',
                // icon: 'head',
                activeIcon: 'head'
            },
            {
                text: '十个字十个字十个字啊',
                // icon: 'head',
                activeIcon: 'head'
            },
            {
                text: '十个字十个字十个字啊',
                // icon: 'head',
                activeIcon: 'head'
            },
            {
                text: '步骤三'
            }
        ],
        step: 0
    },
    feedItemTap() {
        console.log('feed-item 点击回调');
    },
    prev() {
        this.data.step > 0 && this.setData({
            step: this.data.step - 1
        });
    },

    next() {
        console.log('下一步', this.data);
        this.data.step < this.data.steps.length && this.setData({
            step: this.data.step + 1
        });
    }
});
